import click


def get_interfaces(conn, ip_address):
    filtering = {
        'resource': 'ec2_network_interface',
    }
    interfaces = conn.find(filtering)

    interfaces = [
        i for i in interfaces
        if (
                   'PrivateIpAddress' in i and
                   ip_address == i['PrivateIpAddress']
           ) or (
                   'Association' in i and
                   'PublicIp' in i['Association'] and
                   ip_address == i['Association']['PublicIp']
           )
    ]

    [i.update({'aws_profile': conn.profile}) for i in interfaces]

    return interfaces


@click.argument('address', default=False)
@click.command()
def ip(address):
    """Find ip in aws account(s)"""
    from awssearch.config import connections

    o = []
    if address:
        for conn in connections:
            o += get_interfaces(conn, address)

    else:
        import sys
        for line in sys.stdin:
            address = line.replace('\n', '')
            for conn in connections:
                o += get_interfaces(conn, address)

    from awssearch.output import output
    output(o)


if __name__ == '__main__':
    ip()



import os
import subprocess
import logging


def clean(stream):
    try:
        return [line.decode("utf-8").replace('\n', '') for line in stream]
    except UnicodeDecodeError:
        return [line.decode("ISO-8859-1").replace('\n', '') for line in stream]


def sh(command, stdin=None):
    """
    Executa um comando via ssh passando stdin como entrada do comando
    :param command: comando
    :param stdin: entrada
    :return: saída do comando
    """
    if stdin:
        read, write = os.pipe()
        os.write(write, stdin.encode())
        os.close(write)
    else:
        read = None

    process = subprocess.Popen(
        command,
        shell=True,
        stdin=read,
        stdout=subprocess.PIPE,
        stderr=subprocess.PIPE
    )

    output = process.stdout.readlines()
    error = process.stderr.readlines()

    output = clean(output)
    error = clean(error)
    result = output + error

    # loglevel = logging.info if not len(error) else logging.warning
    loglevel = logging.info
    loglevel(
        "command = `%s`\n"
        "output = '%s'"
        % (command, result)
    )

    return output + error



import pinkboto
from awssearch.sh import sh
from awssearch.cli.cli import aws_profiles

connections = []
if not aws_profiles:
    for p in sh("grep -oP '(?<=^\[)\w+(?=\])' ~/.aws/credentials"):
        connections += [
            pinkboto.aws(profile=p, region='us-east-1', cache=None)
        ]
else:
    aws_profiles = aws_profiles.split(',')
    for aws_profile in aws_profiles:
        connections += [
            pinkboto.aws(profile=aws_profile, region='us-east-1', cache=None)
        ]



def output(dics):
    from awssearch.cli.cli import output_format
    if output_format == "json":
        return json(dics)
    if output_format == "csv":
        return csv(dics)


def csv(dics, keys=None):
    """
    Create a CSV from a dictionary list
    :param dics: dictionary list
    :param keys: Optional, subset of keys. Default is all keys.
    :return: None
    """
    if isinstance(dics, dict):
        dics = [dics]

    if not keys:
        keys = sorted(set().union(*(d.keys() for d in dics)))

    import csv
    import io
    output = io.StringIO()

    dict_writer = csv.DictWriter(output, keys)
    dict_writer.writeheader()
    dict_writer.writerows(dics)
    contents = output.getvalue()

    print(contents)


def default(o):
    import datetime
    if isinstance(o, (datetime.date, datetime.datetime)):
        return o.isoformat()


def json(dics):
    import json
    print(json.dumps(
        dics,
        sort_keys=True,
        indent=2,
        default=default,
    ))









import click


aws_profiles = output_format = None


@click.group()
@click.option('--verbose', '-v', is_flag=True, default=False,
              help='Enables verbose mode.')
@click.option('--profile', '-p',
              help='AWS Profile, if not set check all profiles')
@click.option('--output', '-o', default="json",
              help='Output format: json, csv')
def cli(verbose, profile, output):
    """Command line interface for the awssearch package"""
    if verbose:
        import logging
        logging.getLogger().setLevel(logging.INFO)

    global aws_profiles
    aws_profiles = profile

    global output_format
    output_format = output


@click.command()
def version():
    """Display the current version."""
    import pkg_resources  # part of setuptools
    v = pkg_resources.require("awssearch")[0].version
    click.echo(f'version: {v}')


cli.add_command(version)

from .ip import ip
cli.add_command(ip.ip)

if __name__ == '__main__':
    cli()



from setuptools import setup

setup(
    name="awssearch",
    version="0.0.1",
    description="A AWS Search tool",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/Hotmart-Org/awssearch",
    author="Jonatas Renan Camilo Alves",
    author_email="jonatas.alves@hotmart.com",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ],
    keywords='aws search tool',
    packages=['awssearch'],
    install_requires=[
        'aws', 'pinkboto'
    ],
    include_package_data=True,
    entry_points={'console_scripts': ['awssearch = awssearch.cli.cli:cli']}
)
